@@ -14,10 +14,11 @@ from typing import Dict, Optional
 class Network:
     lcd_endpoint: str
     grpc_endpoint: str
+    tendermint_rpc_endpoint: str
     chain_id: str
-    fee_denom: str
     env: str
-    websocket_endpoint: str = None
+    websocket_endpoint: str
+    fee_denom: str = "unibi"
 
     def __post_init__(self):
         """
@@ -27,9 +28,9 @@ class Network:
             self.env = "custom"
 
     @classmethod
-    def devnet(cls) -> "Network":
+    def customnet(cls) -> "Network":
         """
-        Devnet is the network used for testing and debugging of the network. It is unstable and the version can change.
+        Custom is the network configured from ENV variables. Defaults to localnet if no ENV variables are provided.
 
         Raises:
             KeyError: If the values are not set in the testing environment, this will raise an exception.
@@ -38,10 +39,15 @@ class Network:
             Network: The updated Network object.
         """
         chain_config: Dict[str, Optional[str]] = {
-            "HOST": os.getenv("HOST"),
-            "GRPC_PORT": os.getenv("GRPC_PORT"),
-            "LCD_PORT": os.getenv("LCD_PORT"),
-            "CHAIN_ID": os.getenv("CHAIN_ID"),
+            "LCD_ENDPOINT": os.getenv("LCD_ENDPOINT", "http://localhost:1317"),
+            "GRPC_ENDPOINT": os.getenv("GRPC_ENDPOINT", "localhost:9090"),
+            "TENDERMINT_RPC_ENDPOINT": os.getenv(
+                "TENDERMINT_RPC_ENDPOINT", "http://localhost:26657"
+            ),
+            "WEBSOCKET_ENDPOINT": os.getenv(
+                "WEBSOCKET_ENDPOINT", "ws://localhost:26657/websocket"
+            ),
+            "CHAIN_ID": os.getenv("CHAIN_ID", "nibiru-localnet-0"),
         }
         for name, env_var in chain_config.items():
             if env_var is None:
@@ -55,9 +61,10 @@ class Network:
                 )
 
         return cls(
-            lcd_endpoint=f'http://{chain_config["HOST"]}:{chain_config["LCD_PORT"]}',
-            grpc_endpoint=f'{chain_config["HOST"]}:{chain_config["GRPC_PORT"]}',
-            websocket_endpoint=os.getenv("WEBSOCKET_ENDPOINT"),
+            lcd_endpoint=chain_config["LCD_ENDPOINT"],
+            grpc_endpoint=chain_config["GRPC_ENDPOINT"],
+            tendermint_rpc_endpoint=chain_config["TENDERMINT_RPC_ENDPOINT"],
+            websocket_endpoint=chain_config["WEBSOCKET_ENDPOINT"],
             chain_id=chain_config["CHAIN_ID"],
             fee_denom='unibi',
             env="devnet",
@@ -75,6 +82,7 @@ class Network:
         return cls(
             lcd_endpoint='https://lcd.testnet-3.nibiru.fi',
             grpc_endpoint='grpc.testnet-3.nibiru.fi',
+            tendermint_rpc_endpoint='https://rpc.testnet-3.nibiru.fi',
             websocket_endpoint='wss://rpc.testnet-3.nibiru.fi/websocket',
             chain_id='nibiru-testnet-3',
             fee_denom='unibi',
@@ -89,7 +97,7 @@ class Network:
         raise NotImplementedError
 
     @classmethod
-    def local(cls) -> "Network":
+    def localnet(cls) -> "Network":
         """
         Localnet is the network you would expect to connect to if you run `make localnet` from the nibiru repository.
         It allows you to update locally the golang codebase to checkout the behavior of the chain with different changes
@@ -101,6 +109,8 @@ class Network:
         return cls(
             lcd_endpoint='http://localhost:1317',
             grpc_endpoint='localhost:9090',
+            tendermint_rpc_endpoint='http://localhost:26657',
+            websocket_endpoint='ws://localhost:26657/websocket',
             chain_id='nibiru-localnet-0',
             fee_denom='unibi',
             env='local',
